---
layout: default
title: "GraphQL API Reference"
permalink: reference/graphql-apis
type: Reference
abstract: 'Meshery GraphQL API Documentation and Reference'
---

<!---
  This documentation is auto generated by a script.

  Please do not edit this file directly, check compile_docs task on docs/Rakefile.
--->

Self-generated API documentation for Meshery's GraphQL API. The API can be explored interactively using the [GraphQL Playground](./extensibility). Documentation is generated from Meshery's GraphQL schema. Each table below documents a GraphQL type.

WARNING:
Fields that are deprecated are marked with **{warning-solid}**.

<!-- vale off -->

## `Query` type

The `Query` type contains the API's top-level entry points for all executable queries.

### `Query.connectToNats`

Check is Meshey Server is connected to NATS, if not connect to the NATS Server.

###### **Returns** [`Status!`](#status).

### `Query.deployMeshsync`

Check the Meshsync Status and deploy if not enabled.

###### **Returns** [`Status!`](#status).

### `Query.fetchAllResults`

Query for fetching all results for profile ID.

###### **Returns** [`PerfPageResult!`](#perfpageresult).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="queryfetchallresultsselector"></a>`selector` | [`PageFilter!`](#pagefilter) |  |

### `Query.fetchResults`

Query for fetching all results for profile ID.

###### **Returns** [`PerfPageResult!`](#perfpageresult).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="queryfetchresultsprofileid"></a>`profileID` | [`String!`](#string) |  |
| <a id="queryfetchresultsselector"></a>`selector` | [`PageFilter!`](#pagefilter) |  |

### `Query.getAvailableAddons`

Query details about Addons available (Eg. Prometheus and Grafana).

###### **Returns** [`[AddonList!]!`](#addonlist).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="querygetavailableaddonsselector"></a>`selector` | [`MeshType`](#meshtype) | Select Mesh Type. |

### `Query.getAvailableNamespaces`

Query available Namesapces in your cluster.

###### **Returns** [`[NameSpace!]!`](#namespace).

### `Query.getControlPlanes`

Query Control Plane data for a Service Mesh (or all) in your cluster.

###### **Returns** [`[ControlPlane!]!`](#controlplane).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="querygetcontrolplanesfilter"></a>`filter` | [`ServiceMeshFilter`](#servicemeshfilter) | Filter Control Plane Query. |

### `Query.getDataPlanes`

Query Data Plane information for a Service Mesh (or all) in your cluster.

###### **Returns** [`[DataPlane!]!`](#dataplane).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="querygetdataplanesfilter"></a>`filter` | [`ServiceMeshFilter`](#servicemeshfilter) | Filter Control Plane Query. |

### `Query.getMeshsyncStatus`

Check the Meshsync Status.

###### **Returns** [`OperatorControllerStatus!`](#operatorcontrollerstatus).

### `Query.getNatsStatus`

Check is Meshey Server is connected to NATS.

###### **Returns** [`OperatorControllerStatus!`](#operatorcontrollerstatus).

### `Query.getOperatorStatus`

Query status of Meshery Operator in your cluster.

###### **Returns** [`OperatorStatus`](#operatorstatus).

### `Query.getPerfResult`

Query for performance result.

###### **Returns** [`MesheryResult`](#mesheryresult).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="querygetperfresultid"></a>`id` | [`ID!`](#id) |  |

### `Query.getPerformanceProfiles`

Query for fetching all results for profile ID.

###### **Returns** [`PerfPageProfiles!`](#perfpageprofiles).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="querygetperformanceprofilesselector"></a>`selector` | [`PageFilter!`](#pagefilter) |  |

### `Query.resyncCluster`

Query to resync the cluster discovery.

###### **Returns** [`Status!`](#status).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="queryresyncclusterselector"></a>`selector` | [`ReSyncActions`](#resyncactions) | Selector to control several resync actions. |

## `Mutation` type

The `Mutation` type contains all the mutations you can execute.

All mutations receive their arguments in a single input object named `input`.

### `Mutation.changeAddonStatus`

Change the Addon Status.

###### **Input type:** `AddonStatusInput`

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="mutationchangeaddonstatusselector"></a>`selector` | [`MeshType`](#meshtype) | Filter by Serice Mesh. |
| <a id="mutationchangeaddonstatustargetstatus"></a>`targetStatus` | [`Status!`](#status) | Desired Status. |

###### **Returns** [`Status!`](#status).

### `Mutation.changeOperatorStatus`

Change the Operator Status.

###### **Input type:** `OperatorStatusInput`

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="mutationchangeoperatorstatustargetstatus"></a>`targetStatus` | [`Status!`](#status) | Desired status for Meshery Operator. |

###### **Returns** [`Status!`](#status).

## `Subscription` type

The `Subscription` type contains all the Subscriptions you can listen to.

### `Subscription.listenToAddonState`

Listen to changes in status of Addons available (Eg. Prometheus and Grafana).

###### **Returns** [`[AddonList!]!`](#addonlist).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="subscriptionlistentoaddonstateselector"></a>`selector` | [`MeshType`](#meshtype) | Select Mesh Type. |

### `Subscription.listenToControlPlaneState`

Listen to changes in Control Plane data for a Service Mesh (or all) in your cluster.

###### **Returns** [`[ControlPlane!]!`](#controlplane).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="subscriptionlistentocontrolplanestatefilter"></a>`filter` | [`ServiceMeshFilter`](#servicemeshfilter) | Filter Control Plane Query. |

### `Subscription.listenToDataPlaneState`

Listen to changes in Data Plane data for a Service Mesh (or all) in your cluster.

###### **Returns** [`[DataPlane!]!`](#dataplane).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="subscriptionlistentodataplanestatefilter"></a>`filter` | [`ServiceMeshFilter`](#servicemeshfilter) | Filter Control Plane Query. |

### `Subscription.listenToMeshSyncEvents`

Listen to changes in the list of available Namesapces in your cluster.

###### **Returns** [`OperatorControllerStatus!`](#operatorcontrollerstatus).

### `Subscription.listenToOperatorState`

Listen to changes in status of Meshery Operator in your cluster.

###### **Returns** [`OperatorStatus!`](#operatorstatus).

### `Subscription.subscribeBrokerConnection`

Listen to changes in Broker (NATS) Connection.

###### **Returns** [`Boolean!`](#boolean).

### `Subscription.subscribePerfProfile`

Listen to changes in Performance Profile.

###### **Returns** [`MesheryResult!`](#mesheryresult).

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="subscriptionsubscribeperfprofileprofileid"></a>`profileID` | [`String!`](#string) |  |

## Object types

Object types represent the resources that the Meshery GraphQL API can return.
They contain _fields_. Each field has its own type, which will either be one of the
basic GraphQL [scalar types](https://graphql.org/learn/schema/#scalar-types)
(e.g.: `String` or `Boolean`) or other object types. Fields may have arguments.
Fields with arguments are exactly like top-level queries, and are listed beneath
the table of fields for each object type.

For more information, see
[Object Types and Fields](https://graphql.org/learn/schema/#object-types-and-fields)
on `graphql.org`.

### `AddonList`

Deatils about the Addon Component.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="addonlistendpoint"></a>`endpoint` | [`String!`](#string) | Endpoint (if applicable). |
| <a id="addonlistname"></a>`name` | [`String!`](#string) | Name. |
| <a id="addonlistowner"></a>`owner` | [`String!`](#string) | Owner. |

### `Container`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="containercontainername"></a>`containerName` | [`String!`](#string) |  |
| <a id="containercontrolplanemembername"></a>`controlPlaneMemberName` | [`String!`](#string) |  |
| <a id="containerimage"></a>`image` | [`String!`](#string) |  |
| <a id="containerports"></a>`ports` | [`[Container_Port]`](#container_port) | args: NOT IMPLEMENTED. |
| <a id="containerresources"></a>`resources` | [`Any`](#any) | env: NOT IMPLEMENTED,. |
| <a id="containerstatus"></a>`status` | [`Container_Status`](#container_status) |  |

### `Container_Port`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="container_portcontainerport"></a>`containerPort` | [`Int!`](#int) |  |
| <a id="container_portname"></a>`name` | [`String`](#string) |  |
| <a id="container_portprotocol"></a>`protocol` | [`String!`](#string) |  |

### `Container_Status`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="container_statuscontainerid"></a>`containerID` | [`Any`](#any) |  |
| <a id="container_statuscontainerstatusname"></a>`containerStatusName` | [`String!`](#string) |  |
| <a id="container_statusimage"></a>`image` | [`String!`](#string) |  |
| <a id="container_statusimageid"></a>`imageID` | [`Any`](#any) |  |
| <a id="container_statuslaststate"></a>`lastState` | [`Any`](#any) |  |
| <a id="container_statusready"></a>`ready` | [`Boolean!`](#boolean) |  |
| <a id="container_statusrestartcount"></a>`restartCount` | [`Any`](#any) |  |
| <a id="container_statusstarted"></a>`started` | [`Boolean!`](#boolean) | image: String! imageID: String! containerID: String!. |
| <a id="container_statusstate"></a>`state` | [`Any`](#any) |  |

### `ControlPlane`

Control Plane data for a particular Mesh.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="controlplanemembers"></a>`members` | [`[ControlPlaneMember!]!`](#controlplanemember) | Members of the Mesh. |
| <a id="controlplanename"></a>`name` | [`String!`](#string) | Service Mesh Name. |

### `ControlPlaneMember`

Member Details.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="controlplanemembercomponent"></a>`component` | [`String!`](#string) | Component. |
| <a id="controlplanememberdata_planes"></a>`data_planes` | [`[Container!]`](#container) | DataPlanes. |
| <a id="controlplanemembername"></a>`name` | [`String!`](#string) | Name. |
| <a id="controlplanemembernamespace"></a>`namespace` | [`String!`](#string) | Namespace. |
| <a id="controlplanememberversion"></a>`version` | [`String!`](#string) | Version. |

### `DataPlane`

Data Plane for a particular Mesh.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="dataplanename"></a>`name` | [`String!`](#string) | Service Mesh Name. |
| <a id="dataplaneproxies"></a>`proxies` | [`[Container!]!`](#container) | Members of the Mesh. |

### `Error`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="errorcode"></a>`code` | [`String!`](#string) | Error Code. |
| <a id="errordescription"></a>`description` | [`String!`](#string) | Error Details. |

### `MesheryResult`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="mesheryresultcreated_at"></a>`created_at` | [`String`](#string) |  |
| <a id="mesheryresultmesh"></a>`mesh` | [`String`](#string) |  |
| <a id="mesheryresultmeshery_id"></a>`meshery_id` | [`String`](#string) |  |
| <a id="mesheryresultname"></a>`name` | [`String`](#string) |  |
| <a id="mesheryresultperformance_profile"></a>`performance_profile` | [`String`](#string) |  |
| <a id="mesheryresultrunner_results"></a>`runner_results` | [`Map`](#map) |  |
| <a id="mesheryresultserver_board_config"></a>`server_board_config` | [`String`](#string) |  |
| <a id="mesheryresultserver_metrics"></a>`server_metrics` | [`String`](#string) |  |
| <a id="mesheryresulttest_id"></a>`test_id` | [`String`](#string) |  |
| <a id="mesheryresulttest_start_time"></a>`test_start_time` | [`String`](#string) |  |
| <a id="mesheryresultupdated_at"></a>`updated_at` | [`String`](#string) |  |
| <a id="mesheryresultuser_id"></a>`user_id` | [`String`](#string) |  |

### `NameSpace`

Type to define a k8s Namespace.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="namespacenamespace"></a>`namespace` | [`String!`](#string) | Namespace Name. |

### `OperatorControllerStatus`

Controllers of Meshery Operator.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="operatorcontrollerstatuserror"></a>`error` | [`Error`](#error) | Controller Error Log. |
| <a id="operatorcontrollerstatusname"></a>`name` | [`String!`](#string) | Controller Name. |
| <a id="operatorcontrollerstatusstatus"></a>`status` | [`Status!`](#status) | Controller Status. |
| <a id="operatorcontrollerstatusversion"></a>`version` | [`String!`](#string) | Controller Verison. |

### `OperatorStatus`

Status of Meshery Operator and its controllers.

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="operatorstatuscontrollers"></a>`controllers` | [`[OperatorControllerStatus!]!`](#operatorcontrollerstatus) | Details about various Controllers of Meshery Operator. |
| <a id="operatorstatuserror"></a>`error` | [`Error`](#error) | Error Logs encountered by Meshery Operator. |
| <a id="operatorstatusstatus"></a>`status` | [`Status!`](#status) | Status of Meshery Operator. |
| <a id="operatorstatusversion"></a>`version` | [`String!`](#string) | Verion of Meshery Operator. |

### `PerfPageProfiles`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="perfpageprofilespage"></a>`page` | [`Int!`](#int) |  |
| <a id="perfpageprofilespage_size"></a>`page_size` | [`Int!`](#int) |  |
| <a id="perfpageprofilesprofiles"></a>`profiles` | [`[PerfProfile]`](#perfprofile) |  |
| <a id="perfpageprofilestotal_count"></a>`total_count` | [`Int!`](#int) |  |

### `PerfPageResult`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="perfpageresultpage"></a>`page` | [`Int!`](#int) |  |
| <a id="perfpageresultpage_size"></a>`page_size` | [`Int!`](#int) |  |
| <a id="perfpageresultresults"></a>`results` | [`[MesheryResult]`](#mesheryresult) |  |
| <a id="perfpageresulttotal_count"></a>`total_count` | [`Int!`](#int) |  |

### `PerfProfile`

#### **Fields**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="perfprofileconcurrent_request"></a>`concurrent_request` | [`Int!`](#int) |  |
| <a id="perfprofilecontent_type"></a>`content_type` | [`String`](#string) |  |
| <a id="perfprofilecreated_at"></a>`created_at` | [`String`](#string) |  |
| <a id="perfprofileduration"></a>`duration` | [`String!`](#string) |  |
| <a id="perfprofileendpoints"></a>`endpoints` | [`[String]`](#string) |  |
| <a id="perfprofileid"></a>`id` | [`String!`](#string) |  |
| <a id="perfprofilelast_run"></a>`last_run` | [`String`](#string) |  |
| <a id="perfprofileload_generators"></a>`load_generators` | [`[String]`](#string) |  |
| <a id="perfprofilename"></a>`name` | [`String`](#string) |  |
| <a id="perfprofileqps"></a>`qps` | [`Int`](#int) |  |
| <a id="perfprofilerequest_body"></a>`request_body` | [`String`](#string) |  |
| <a id="perfprofilerequest_cookies"></a>`request_cookies` | [`String`](#string) |  |
| <a id="perfprofilerequest_headers"></a>`request_headers` | [`String`](#string) |  |
| <a id="perfprofileservice_mesh"></a>`service_mesh` | [`String`](#string) |  |
| <a id="perfprofiletotal_results"></a>`total_results` | [`Int`](#int) |  |
| <a id="perfprofileupdated_at"></a>`updated_at` | [`String`](#string) |  |
| <a id="perfprofileuser_id"></a>`user_id` | [`String!`](#string) |  |

## Enumeration types

Also called _Enums_, enumeration types are a special kind of scalar that
is restricted to a particular set of allowed values.

For more information, see
[Enumeration Types](https://graphql.org/learn/schema/#enumeration-types)
on `graphql.org`.

### `MeshType`

Service Mesh Types.

| Value | Description |
| ----- | ----------- |
| <a id="meshtypeall_mesh"></a>`ALL_MESH` | All meshes that Meshery supports. |
| <a id="meshtypeapp_mesh"></a>`APP_MESH` | AWS App Mesh. |
| <a id="meshtypecitrix_service_mesh"></a>`CITRIX_SERVICE_MESH` | Citrix Service Mesh. |
| <a id="meshtypeconsul"></a>`CONSUL` | Consul by HashiCorp. |
| <a id="meshtypeinvalid_mesh"></a>`INVALID_MESH` | Invalid Mesh. |
| <a id="meshtypeistio"></a>`ISTIO` | Istio Service Mesh. |
| <a id="meshtypekuma"></a>`KUMA` | Kuma. |
| <a id="meshtypelinkerd"></a>`LINKERD` | LinkerD Service Mesh. |
| <a id="meshtypenetwork_service_mesh"></a>`NETWORK_SERVICE_MESH` | Network Service Mesh. |
| <a id="meshtypenginx_service_mesh"></a>`NGINX_SERVICE_MESH` | NGINX Service Mesh. |
| <a id="meshtypeoctarine"></a>`OCTARINE` | Octarine Mesh. |
| <a id="meshtypeopen_service_mesh"></a>`OPEN_SERVICE_MESH` | Open Service Mesh. |
| <a id="meshtypetanzu"></a>`TANZU` | VMware Tanzu Service Mesh. |
| <a id="meshtypetraefik_mesh"></a>`TRAEFIK_MESH` | Traefik Mesh. |

### `Status`

| Value | Description |
| ----- | ----------- |
| <a id="statusconnected"></a>`CONNECTED` | Connected (Applicable only for NATS status for now). |
| <a id="statusdisabled"></a>`DISABLED` | Disabled. |
| <a id="statusenabled"></a>`ENABLED` | Enabled. |
| <a id="statusprocessing"></a>`PROCESSING` | Processing. |
| <a id="statusunknown"></a>`UNKNOWN` | Unknown. |

## Scalar types

Scalar values are atomic values, and do not have fields of their own.
Basic scalars include strings, boolean values, and numbers. This schema also
defines various custom scalar values, such as types for times and dates.

This schema includes custom scalar types for identifiers, with a specific type for
each kind of object.

For more information, read about [Scalar Types](https://graphql.org/learn/schema/#scalar-types) on `graphql.org`.

### `Any`

### `Boolean`

Represents `true` or `false` values.

### `ID`

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as `"VXNlci0xMA=="`) or integer (such as `4`) input value will be accepted as an ID.

### `Int`

Represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1.

### `Map`

### `String`

Represents textual data as UTF-8 character sequences. This type is most often used by GraphQL to represent free-form human-readable text.

### `Time`

## Input types

Types that may be used as arguments (all scalar types may also
be used as arguments).

Only general use input types are listed here. For mutation input types,
see the associated mutation type above.

For more information, read about [Scalar Types](https://graphql.org/learn/schema/#input-types) on `graphql.org`.

### `PageFilter`

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="pagefilterfrom"></a>`from` | [`String`](#string) |  |
| <a id="pagefilterorder"></a>`order` | [`String`](#string) |  |
| <a id="pagefilterpage"></a>`page` | [`String!`](#string) |  |
| <a id="pagefilterpagesize"></a>`pageSize` | [`String!`](#string) |  |
| <a id="pagefiltersearch"></a>`search` | [`String`](#string) |  |
| <a id="pagefilterto"></a>`to` | [`String`](#string) |  |

### `ReSyncActions`

Type ReSyncActions define the actions involved during resync.

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="resyncactionsresync"></a>`ReSync` | [`String!`](#string) |  |
| <a id="resyncactionscleardb"></a>`clearDB` | [`String!`](#string) |  |

### `ServiceMeshFilter`

Filter Control Plane Query.

#### **Arguments**

| Name | Type | Description |
| ---- | ---- | ----------- |
| <a id="servicemeshfiltertype"></a>`type` | [`MeshType`](#meshtype) | Filter by Service Mesh. |
